# Generate devel rpm
%global with_devel 0
# Build with debug info rpm
%global with_debug 0
# Run unit tests
%global with_tests 0
# Build test binaries
%global with_test_binaries 0

%if 0%{?with_debug}
%global _dwz_low_mem_die_limit 0
%else
%global debug_package   %{nil}
%endif

%global git_commit 7635c4343c78a0a7bfe105f34985fcfc7c523a0f
%global git_shortcommit  %(c=%{git_commit}; echo ${c:0:7})

%global provider        github
%global provider_tld    com
%global project         maistra
%global repo            istio-operator

# are we building community or product rpms
%global community_build  false

# https://github.com/maistra/istio-operator
%global provider_prefix %{provider}.%{provider_tld}/%{project}

# Use /usr/local as base dir, once upstream heavily depends on that
%global _prefix /usr/local

Name:           servicemesh-operator
Version:        2.0.11
Release:        1%{?dist}
Summary:        A Kubernetes operator to manage Istio.
License:        ASL 2.0
URL:            https://%{provider_prefix}/%{repo}

Source0:        https://%{provider_prefix}/%{repo}/archive/%{git_commit}/%{repo}-%{git_commit}.tar.gz
#Patch0:         0001-MAISTRA-1464-Update-gopkg.in-yaml.v2-to-v2.3.0.patch
#Patch1:         0002-MAISTRA-1071-Add-manifest-namespace-validation.patch
Patch20:        0020-goldpanda.patch
Patch1000:      1000-update-network-policy.patch

# e.g. el6 has ppc64 arch without gcc-go, so EA tag is required
ExclusiveArch:  x86_64 ppc64le s390x
# If go_compiler is not set to 1, there is no virtual provide. Use golang instead.
BuildRequires:  golang >= 1.9

%description
Istio-operator is a kubernetes operator to manage the lifecycle of Istio.

%if 0%{?with_devel}
%package devel
Summary:       %{summary}
BuildArch: x86_64 ppc64le s390x

%description devel
Istio-operator is a kubernetes operator to manage the lifecycle of Istio.
%endif

%prep

rm -rf OPERATOR

mkdir -p OPERATOR/src/github.com/maistra/istio-operator
tar zxf %{SOURCE0} -C OPERATOR/src/github.com/maistra/istio-operator --strip=1

pushd OPERATOR/src/github.com/maistra/istio-operator
#%patch0 -p1
#%patch1 -p1
%patch20 -p1
%patch1000 -p1
popd

%build
cd OPERATOR
export GOPATH=$(pwd):%{gopath}
%ifarch ppc64le s390x
export MINIMUM_SUPPORTED_VERSION=v1.1
%endif
pushd src/github.com/maistra/istio-operator/
COMMUNITY=%{community_build} GO111MODULE=on VERSION=%{version}-%{release} GITREVISION=%{git_shortcommit} GITSTATUS=Clean GITTAG=%{version} GIT_UPSTREAM_REMOTE="_DUMMY_" OFFLINE_BUILD="true" MINIMUM_SUPPORTED_VERSION=${MINIMUM_SUPPORTED_VERSION} make compile collect-resources
popd

%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT%{_bindir}
pushd OPERATOR/src/github.com/maistra/istio-operator/tmp/_output/bin/

./istio-operator --version

%if 0%{?with_debug}
    cp -pav istio-operator $RPM_BUILD_ROOT%{_bindir}/
%else
    mkdir stripped

    echo "Dumping dynamic symbols"
        nm -D istio-operator --format=posix --defined-only \
  | awk '{ print $1 }' | sort > dynsyms

       echo "Dumping function symbols"
       nm istio-operator --format=posix --defined-only \
  | awk '{ if ($2 == "T" || $2 == "t" || $2 == "D") print $1 }' \
  | sort > funcsyms

        echo "Grabbing other function symbols"
        comm -13 dynsyms funcsyms > keep_symbols


  COMPRESSED_NAME="operator_debuginfo"
        echo "remove unnecessary debug info"
        objcopy -S --remove-section .gdb_index --remove-section .comment \
  --keep-symbols=keep_symbols "istio-operator" "${COMPRESSED_NAME}"

        echo "stripping operator"
        strip -o "stripped/istio-operator" -s istio-operator


        echo "compress debugdata for istio-operator into ${COMPRESSED_NAME}.xz"
        xz "${COMPRESSED_NAME}"

        echo "inject compressed data into .gnu_debugdata for istio-operator"
        objcopy --add-section ".gnu_debugdata=${COMPRESSED_NAME}.xz" "stripped/istio-operator"

        cp -pav "stripped/istio-operator" "${RPM_BUILD_ROOT}%{_bindir}/"
%endif
popd

mkdir -p $RPM_BUILD_ROOT%{_datadir}/istio-operator/helm
TEMPLATES_DIR=$RPM_BUILD_ROOT/%{_datadir}/istio-operator/default-templates
mkdir -p ${TEMPLATES_DIR}

pushd OPERATOR/src/github.com/maistra/istio-operator/tmp/_output/resources
# install the charts
cp -rpavT helm/ $RPM_BUILD_ROOT%{_datadir}/istio-operator/helm
# install the templates
cp -rpavT default-templates/ $RPM_BUILD_ROOT%{_datadir}/istio-operator/default-templates

#install manifests
cp -rpavT manifests/ $RPM_BUILD_ROOT/manifests
popd

%files
%{_bindir}/istio-operator
%{_datadir}/istio-operator
/manifests

%changelog
* Mon Aug 08 2022 Product Release - 2.0.11-1
- Update to latest release

* Mon Jun 06 2022 Product Release - 2.0.10-1
- Update to latest release

* Thu Mar 24 2022 Product Release - 2.0.9-3
- Update to latest release

* Wed Mar 23 2022 Product Release - 2.0.9-2
- Update to latest release

* Tue Mar 22 2022 Product Release - 2.0.9-1
- Update to latest release

* Tue Sep 14 2021 Product Release - 2.0.8-2
- Update to latest release

* Fri Sep 10 2021 Product Release - 2.0.8-1
- Update to latest release

* Fri Aug 20 2021 Product Release - 2.0.7-2
- Update to latest release

* Mon Aug 16 2021 Product Release - 2.0.7-1
- Update to latest release

* Tue Jul 13 2021 Product Release - 2.0.6-4
- Update to latest release

* Wed Jul 07 2021 Product Release - 2.0.6-3
- Update to latest release

* Thu Jun 17 2021 Product Release - 2.0.6-2
- Update to latest release

* Thu Jun 17 2021 Product Release - 2.0.6-1
- Update to latest release

* Fri May 21 2021 Product Release - 2.0.5-3
- Updating for 2.0.5.2 patch release

* Fri May 21 2021 Product Release - 2.0.5-2
- Updating for 2.0.5 patch release

* Fri May 21 2021 Product Release - 2.0.6-1
- Update to latest release

* Sat May 15 2021 Product Release - 2.0.5-1
- Update to latest release

* Tue May 11 2021 Product Release - 2.0.4-3
- Update to latest release

* Fri May 07 2021 Product Release - 2.0.4-2
- Update to latest release

* Fri May 07 2021 Product Release - 2.0.4-1
- Update to latest release

* Tue Apr 13 2021 Product Release - 2.0.3-2
- Update to latest release

* Sun Apr 11 2021 Product Release - 2.0.3-1
- Update to latest release

* Wed Jan 27 2021 Product Release - 2.0.2-3
- Update to latest release

* Wed Jan 27 2021 Product Release - 2.0.2-2
- Update to latest release

* Tue Jan 19 2021 Product Release - 2.0.2-1
- Update to latest release

* Sat Jan 9 2021 Product Release - 2.0.1-6
- Update to latest release

* Fri Dec 18 2020 Product Release - 2.0.1-5
- Update to latest release

* Thu Dec 17 2020 Product Release - 2.0.1-4
- Update to latest release

* Tue Dec 15 2020 Product Release - 2.0.1-3
- Update to latest release

* Sun Dec 13 2020 Product Release - 2.0.1-2
- Update to latest release

* Fri Dec 11 2020 Product Release - 2.0.1-1
- Update to latest release

* Tue Nov 10 2020 Product Release - 2.0.0-13
- Update to latest release

* Tue Nov 10 2020 Product Release - 2.0.0-12
- Update to latest release

* Sat Nov 07 2020 Product Release - 2.0.0-11
- Update to latest release

* Fri Nov 06 2020 Product Release - 2.0.0-10
- Update to latest release

* Tue Nov 03 2020 Product Release - 2.0.0-9
- Update to latest release

* Fri Oct 30 2020 Product Release - 2.0.0-8
- Update to latest release

* Thu Oct 29 2020 Product Release - 2.0.0-7
- Update to latest release

* Wed Oct 28 2020 Product Release - 2.0.0-6
- Update to latest release

* Mon Oct 26 2020 Product Release - 2.0.0-5
- Update to latest release

* Fri Oct 23 2020 Product Release - 2.0.0-4
- Update to latest release

* Fri Oct 23 2020 Product Release - 2.0.0-3
- Update to latest release

* Wed Oct 21 2020 Product Release - 2.0.0-2
- Update to latest release

* Fri Jul 17 2020 Brian Avery - 2.0.0-0
- Update to Maistra 2.0
